module.exports = {
    'env': {
        'browser': true,
        'commonjs': true,
        'es6': true,
        'node': true,
    },
    'extends': [
        'eslint:recommended', 'plugin:vue/base', 'plugin:@typescript-eslint/recommended', 'plugin:vue/essential',
    ],
    'parserOptions': {
        parser: '@typescript-eslint/parser',
        env: { es6: true },
        sourceType: 'module',
    },
    'plugins': [
        'vue',
        '@typescript-eslint',
    ],
    'rules': {
        // 'prettier/prettier': 'warn',
        'keyword-spacing': 'error',
        'camelcase': ['warn', {
            'properties': 'always',
        }],
        'indent': ['error', 4, { SwitchCase: 1, CallExpression: { arguments: 'off' }, ArrayExpression: 'first' }],
        // 'no-else-return': 'error',
        'object-curly-spacing': ['error', 'always'],
        'array-bracket-spacing': ['error', 'never'],
        'semi-spacing': ['error', {
            'before': false,
            'after': true,
        }],
        'rest-spread-spacing': ['error', 'never'],
        'space-in-parens': ['error', 'never'],
        'curly': 'error',
        'semi': ['error', 'always'],
        'no-multi-spaces': ['error', { ignoreEOLComments: true }],
        'no-whitespace-before-property': 'error',
        'no-tabs': ['error', { allowIndentationTabs: true }],

        'no-unused-vars': ['warn', 'all'],
        'no-empty': ['error', { 'allowEmptyCatch': true }],
        'consistent-return': ['warn', { 'treatUndefinedAsUnspecified': true }],
        'eqeqeq': ['warn', 'always'],
        // 'line-comment-position': ['warn', { 'position': 'above' }],
        'max-len': ['warn', {
            'code': 180,
        }],
        'no-undef': 0,
        'no-constant-condition': ['warn', {
            'checkLoops': false,
        }],
        'no-inner-declarations': ['warn'],
        'no-case-declarations': ['warn'],
        // 行尾逗号
        'comma-style': ['error', 'last'],
        'comma-dangle': ['error', {
            'arrays': 'always-multiline',
            'objects': 'always-multiline',
            'imports': 'always-multiline',
            'exports': 'always-multiline',
            'functions': 'only-multiline',
        }],
        'comma-spacing': ['error', {
            'before': false,
            'after': true,
        }],

        // 空格、空行约定
        'unicode-bom': ['warn', 'never'],
        'block-spacing': ['error', 'always'],
        'arrow-spacing': ['error', {
            'before': true,
            'after': true,
        }],
        'space-before-function-paren': ['error', {
            'anonymous': 'never',
            'named': 'never',
            'asyncArrow': 'always',
        }],
        'space-before-blocks': ['error', 'always'],
        'space-infix-ops': ['warn'],
        'space-unary-ops': ['warn', {
            'words': true,
            'nonwords': false,
        }],
        'spaced-comment': ['warn', 'always', {
            'line': {
                'markers': ['/'],
                'exceptions': ['/', '*'],
            },
        },
        ],
        'switch-colon-spacing': ['warn', {
            'before': false,
            'after': true,
        }],
        'eol-last': ['error', 'always'],
        'no-trailing-spaces': ['error', { 'ignoreComments': true }],
        'quotes': [1, 'single'],
        '@typescript-eslint/no-empty-function': 'off',
        '@typescript-eslint/explicit-module-boundary-types':'off',
        'no-multiple-empty-lines': ['error', { 'max': 1 }],
    },
};
